/*
 *  The MIT License
 *
 *  Copyright 2011-2012 Masahiko, SAWAI <masahiko.sawai@gmail.com>.
 *
 *  Permission is hereby granted, free of charge, to any person obtaining a copy
 *  of this software and associated documentation files (the "Software"), to deal
 *  in the Software without restriction, including without limitation the rights
 *  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 *  copies of the Software, and to permit persons to whom the Software is
 *  furnished to do so, subject to the following conditions:
 *
 *  The above copyright notice and this permission notice shall be included in
 *  all copies or substantial portions of the Software.
 *
 *  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 *  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 *  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 *  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 *  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 *  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 *  THE SOFTWARE.
 */
package org.routine_work.simple_battery_logger;

import android.app.Activity;
import android.content.Intent;
import android.os.Bundle;
import android.os.Environment;
import android.view.View;
import android.view.View.OnClickListener;
import android.widget.Button;
import android.widget.TextView;
import java.io.File;
import org.routine_work.simple_battery_logger.service.DeleteAllCsvFileService;
import org.routine_work.simple_battery_logger.util.CsvFilenameFilter;
import org.routine_work.util.Log;
import org.routine_work.simple_battery_logger.util.PreferenceUtils;

public class DeleteAllCsvFileActivity extends Activity
	implements OnClickListener
{

	public static final String LOG_TAG = "simple-battery-logger";

	/**
	 * Called when the activity is first created.
	 */
	@Override
	public void onCreate(Bundle savedInstanceState)
	{
		super.onCreate(savedInstanceState);
		setContentView(R.layout.delete_all_csv_file_activity);

		Button okButton = (Button) findViewById(R.id.ok_button);
		okButton.setOnClickListener(this);
		Button cancelButton = (Button) findViewById(R.id.cancel_button);
		cancelButton.setOnClickListener(this);

		int csvFileCount = getCsvFileCount();
		if (csvFileCount == 0)
		{
			okButton.setVisibility(View.GONE);
		}
		else
		{
			// init confirm message
			String confirmMessage = getResources().getQuantityString(
				R.plurals.delete_csv_file_confirm_message,
				csvFileCount, csvFileCount);
			Log.d(LOG_TAG, "delete csv confirm message => " + confirmMessage);

			TextView confirmMessageTextView = (TextView) findViewById(R.id.delete_csv_file_confirm_message_textview);
			confirmMessageTextView.setText(confirmMessage);
		}

	}

	@Override
	public void onClick(View view)
	{
		int id = view.getId();
		switch (id)
		{
			case R.id.ok_button:
				deleteAllCsvData();
				setResult(RESULT_OK);
				finish();
				break;
			case R.id.cancel_button:
				setResult(RESULT_CANCELED);
				finish();
				break;
		}
	}

	private void deleteAllCsvData()
	{
		Intent intent = new Intent(this, DeleteAllCsvFileService.class);
		startService(intent);
	}

	private int getCsvFileCount()
	{
		int csvFileCount = 0;
		Log.v(LOG_TAG, "Hello");

		String externalStorageState = Environment.getExternalStorageState();
		if (externalStorageState.equalsIgnoreCase(Environment.MEDIA_MOUNTED))
		{
			String csvExportDirectoryName = PreferenceUtils.getCsvExportDirectoryName(this);
			Log.i(LOG_TAG, "csvExportDirectoryName => " + csvExportDirectoryName);

			File externalStorageDirectory = Environment.getExternalStorageDirectory();
			File exportDir = new File(externalStorageDirectory, csvExportDirectoryName);
			if (exportDir.exists())
			{
				File[] csvFiles = exportDir.listFiles(new CsvFilenameFilter());
				if (csvFiles != null)
				{
					csvFileCount = csvFiles.length;
				}
			}
		}

		Log.d(LOG_TAG, "csvFileCount => " + csvFileCount);
		Log.v(LOG_TAG, "Bye");
		return csvFileCount;
	}
}
